@@ -32,7 +32,7 @@
  * we are awaiting payment before giving up?
  */
 #define CHECK_PAYMENT_GENERIC_TIMEOUT GNUNET_TIME_relative_multiply ( \
-    GNUNET_TIME_UNIT_MINUTES, 30)
+          GNUNET_TIME_UNIT_MINUTES, 30)
 
 
 /**
@@ -236,7 +236,7 @@ make_payment_request (const char *order_id,
   TALER_MHD_add_global_headers (resp);
   {
     char *hdr;
-    char *pfx;
+    const char *pfx;
     char *hn;
     struct GNUNET_Buffer hdr_buf = { 0 };
 
@@ -515,7 +515,8 @@ await_payment (struct BackupContext *bc,
   bc->omgh = TALER_MERCHANT_merchant_order_get (SH_ctx,
                                                 SH_backend_url,
                                                 order_id,
-                                                NULL /* our payments are NOT session-bound */,
+                                                NULL /* our payments are NOT session-bound */
+                                                ,
                                                 timeout,
                                                 &check_payment_cb,
                                                 bc);
