@@ -237,8 +237,7 @@ prepare_statements (void *cls)
  * @return #GNUNET_OK on success
  */
 static enum GNUNET_GenericReturnValue
-internal_setup (struct PostgresClosure *pg,
-                bool skip_prepare)
+internal_setup (struct PostgresClosure *pg)
 {
   if (NULL == pg->conn)
   {
@@ -267,11 +266,12 @@ internal_setup (struct PostgresClosure *pg,
 #endif
     struct GNUNET_PQ_Context *db_conn;
 
-    db_conn = GNUNET_PQ_connect_with_cfg (pg->cfg,
-                                          "syncdb-postgres",
-                                          NULL,
-                                          es,
-                                          NULL);
+    db_conn = GNUNET_PQ_connect_with_cfg2 (pg->cfg,
+                                           "syncdb-postgres",
+                                           "sync-",
+                                           es,
+                                           NULL,
+                                           GNUNET_PQ_FLAG_CHECK_CURRENT);
     if (NULL == db_conn)
       return GNUNET_SYSERR;
     pg->conn = db_conn;
@@ -280,8 +280,6 @@ internal_setup (struct PostgresClosure *pg,
     GNUNET_PQ_reconnect_if_down (pg->conn);
   if (pg->init)
     return GNUNET_OK;
-  if (skip_prepare)
-    return GNUNET_OK;
   return prepare_statements (pg);
 }
 
@@ -308,8 +306,7 @@ postgres_preflight (void *cls)
   if (! pg->init)
   {
     if (GNUNET_OK !=
-        internal_setup (pg,
-                        false))
+        internal_setup (pg))
     {
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                   "Failed to ensure DB is initialized\n");
@@ -631,7 +628,8 @@ payment_by_account_cb (void *cls,
 static enum GNUNET_DB_QueryStatus
 postgres_lookup_pending_payments_by_account (void *cls,
                                              const struct
-                                             SYNC_AccountPublicKeyP *account_pub,
+                                             SYNC_AccountPublicKeyP *account_pub
+                                             ,
                                              SYNC_DB_PaymentPendingIterator it,
                                              void *it_cls)
 {
@@ -1283,6 +1281,10 @@ postgres_create_tables (void *cls)
  * @return NULL on error, otherwise a `struct TALER_SYNCDB_Plugin`
  */
 void *
+libsync_plugin_db_postgres_init (void *cls);
+
+/* make compiler happy */
+void *
 libsync_plugin_db_postgres_init (void *cls)
 {
   struct GNUNET_CONFIGURATION_Handle *cfg = cls;
@@ -1305,26 +1307,17 @@ libsync_plugin_db_postgres_init (void *cls)
   }
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_get_value_string (cfg,
-                                             "taler",
+                                             "sync",
                                              "CURRENCY",
                                              &pg->currency))
   {
     GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
-                               "taler",
+                               "sync",
                                "CURRENCY");
     GNUNET_free (pg->sql_dir);
     GNUNET_free (pg);
     return NULL;
   }
-  if (GNUNET_OK !=
-      internal_setup (pg,
-                      true))
-  {
-    GNUNET_free (pg->currency);
-    GNUNET_free (pg->sql_dir);
-    GNUNET_free (pg);
-    return NULL;
-  }
   plugin = GNUNET_new (struct SYNC_DatabasePlugin);
   plugin->cls = pg;
   plugin->create_tables = &postgres_create_tables;
@@ -1350,6 +1343,10 @@ libsync_plugin_db_postgres_init (void *cls)
  * @return NULL (always)
  */
 void *
+libsync_plugin_db_postgres_done (void *cls);
+
+/* make compiler happy */
+void *
 libsync_plugin_db_postgres_done (void *cls)
 {
   struct SYNC_DatabasePlugin *plugin = cls;
