@@ -20,12 +20,14 @@
  * @author Sree Harsha Totakura <sreeharsha@totakura.in>
  */
 #include "platform.h"
-#include "sync_database_plugin.h"
+#include "sync_util.h"
+#include "sync_database_lib.h"
 #include <ltdl.h>
 
 
 struct SYNC_DatabasePlugin *
-SYNC_DB_plugin_load (const struct GNUNET_CONFIGURATION_Handle *cfg)
+SYNC_DB_plugin_load (const struct GNUNET_CONFIGURATION_Handle *cfg,
+                     bool skip_preflight)
 {
   char *plugin_name;
   char *lib_name;
@@ -46,12 +48,24 @@ SYNC_DB_plugin_load (const struct GNUNET_CONFIGURATION_Handle *cfg)
                           "libsync_plugin_db_%s",
                           plugin_name);
   GNUNET_free (plugin_name);
-  plugin = GNUNET_PLUGIN_load (lib_name,
+  plugin = GNUNET_PLUGIN_load (SYNC_project_data (),
+                               lib_name,
                                (void *) cfg);
-  if (NULL != plugin)
-    plugin->library_name = lib_name;
-  else
+  if (NULL == plugin)
+  {
     GNUNET_free (lib_name);
+    return NULL;
+  }
+  plugin->library_name = lib_name;
+  if ( (! skip_preflight) &&
+       (GNUNET_OK !=
+        plugin->preflight (plugin->cls)) )
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "Database not ready. Try running sync-dbinit!\n");
+    SYNC_DB_plugin_unload (plugin);
+    return NULL;
+  }
   return plugin;
 }
 
@@ -70,67 +84,4 @@ SYNC_DB_plugin_unload (struct SYNC_DatabasePlugin *plugin)
 }
 
 
-/**
- * Libtool search path before we started.
- */
-static char *old_dlsearchpath;
-
-
-/**
- * Setup libtool paths.
- */
-void __attribute__ ((constructor))
-plugin_init ()
-{
-  int err;
-  const char *opath;
-  char *path;
-  char *cpath;
-
-  err = lt_dlinit ();
-  if (err > 0)
-  {
-    fprintf (stderr,
-             "Initialization of plugin mechanism failed: %s!\n",
-             lt_dlerror ());
-    return;
-  }
-  opath = lt_dlgetsearchpath ();
-  if (NULL != opath)
-    old_dlsearchpath = GNUNET_strdup (opath);
-  path = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_LIBDIR);
-  if (NULL != path)
-  {
-    if (NULL != opath)
-    {
-      GNUNET_asprintf (&cpath, "%s:%s", opath, path);
-      lt_dlsetsearchpath (cpath);
-      GNUNET_free (path);
-      GNUNET_free (cpath);
-    }
-    else
-    {
-      lt_dlsetsearchpath (path);
-      GNUNET_free (path);
-    }
-  }
-}
-
-
-/**
- * Shutdown libtool.
- */
-void __attribute__ ((destructor))
-plugin_fini ()
-{
-  lt_dlsetsearchpath (old_dlsearchpath);
-  if (NULL != old_dlsearchpath)
-  {
-    GNUNET_free (old_dlsearchpath);
-    old_dlsearchpath = NULL;
-  }
-  lt_dlexit ();
-}
-
-
 /* end of sync_db_plugin.c */
