@@ -28,14 +28,15 @@
 
 
 #define FAILIF(cond)                            \
-  do {                                          \
-    if (! (cond)) { break;}                       \
-    GNUNET_break (0);                           \
-    goto drop;                                     \
-  } while (0)
+        do {                                          \
+          if (! (cond)) { break;}                       \
+          GNUNET_break (0);                           \
+          goto drop;                                     \
+        } while (0)
 
 #define RND_BLK(ptr)                                                    \
-  GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK, ptr, sizeof (*ptr))
+        GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK, ptr, sizeof (* \
+                                                                             ptr))
 
 /**
  * Global return value for the test.  Initially -1, set to 0 upon
@@ -94,7 +95,8 @@ run (void *cls)
   size_t bs;
   void *b = NULL;
 
-  if (NULL == (plugin = SYNC_DB_plugin_load (cfg)))
+  if (NULL == (plugin = SYNC_DB_plugin_load (cfg,
+                                             true)))
   {
     result = 77;
     return;
@@ -277,8 +279,6 @@ main (int argc,
   GNUNET_log_setup (argv[0],
                     "DEBUG",
                     NULL);
-  (void) TALER_project_data_default ();
-  GNUNET_OS_init (SYNC_project_data_default ());
   plugin_name++;
   (void) GNUNET_asprintf (&testname,
                           "%s",
@@ -286,7 +286,7 @@ main (int argc,
   (void) GNUNET_asprintf (&config_filename,
                           "test_sync_db_%s.conf",
                           testname);
-  cfg = GNUNET_CONFIGURATION_create ();
+  cfg = GNUNET_CONFIGURATION_create (SYNC_project_data ());
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_parse (cfg,
                                   config_filename))
